# CMeel console-bridge

[![PyPI version](https://badge.fury.io/py/cmeel-console-bridge.svg)](https://pypi.org/project/cmeel-console-bridge)
[![Release](https://github.com/cmake-wheel/cmeel-console-bridge/actions/workflows/release.yml/badge.svg)](https://github.com/cmake-wheel/cmeel-console-bridge/actions/workflows/release.yml)
[![Build Status](https://api.cirrus-ci.com/github/cmake-wheel/cmeel-console-bridge.svg)](https://cirrus-ci.com/github/cmake-wheel/cmeel-console-bridge)

[console-bridge](https://github.com/ros/console_bridge) distribution for cmeel packages.
